pub struct DiagnosticSet { /* private fields */ }Expand description
A collection of diagnostics.
Implementations
Sourceimpl DiagnosticSet
impl DiagnosticSet
Sourcepub fn new() -> DiagnosticSet
pub fn new() -> DiagnosticSet
Creates a new empty diagnostic set.
Sourcepub fn add(&mut self, diagnostic: Diagnostic)
pub fn add(&mut self, diagnostic: Diagnostic)
Sourcepub fn extend(&mut self, diagnostics: impl IntoIterator<Item = Diagnostic>)
pub fn extend(&mut self, diagnostics: impl IntoIterator<Item = Diagnostic>)
Adds multiple diagnostics to the set.
Sourcepub fn iter(&self) -> impl Iterator<Item = &Diagnostic>
pub fn iter(&self) -> impl Iterator<Item = &Diagnostic>
Returns an iterator over the diagnostics.
Sourcepub fn has_errors(&self) -> bool
pub fn has_errors(&self) -> bool
Returns true if there are any errors in the set.
Sourcepub fn len(&self) -> usize
pub fn len(&self) -> usize
Returns the number of diagnostics.
Examples found in repository?
examples/workflow.rs (line 31)
7fn main() -> Result<(), Box<dyn Error>> {
8 let input = r#"#VRML_SIM R2025a utf8
9
10PROTO ContextAwareBox [
11 field SFInt32 count 2
12 field SFString label "default-label"
13]
14{
15 Group {
16 children [
17 WorldInfo { title "%<= fields.label.value >%|%<= fields.label.defaultValue >%|%<= context.os >%" }
18 %< for (let i = 0; i < fields.count.value; ++i) { >%
19 Transform {
20 translation %<= i >% 0 0
21 children [ Box { size 0.5 0.5 0.5 } ]
22 }
23 %< } >%
24 ]
25 }
26}
27"#;
28
29 let document: Proto = input.parse()?;
30 let diagnostics = document.validate()?;
31 println!("diagnostics: {}", diagnostics.len());
32
33 let mut field_overrides = HashMap::new();
34 field_overrides.insert("count".to_string(), TemplateField::SFInt32(3));
35 field_overrides.insert(
36 "label".to_string(),
37 TemplateField::SFString("override-label".to_string()),
38 );
39
40 let context = RenderContext::default()
41 .with_os("linux")
42 .with_world("/workspace/worlds/example.wbt")
43 .with_webots_version(RenderWebotsVersion::new(
44 "R2025a".to_string(),
45 "0".to_string(),
46 ));
47
48 let options = RenderOptions::default()
49 .with_field_overrides(field_overrides)
50 .with_context(context);
51
52 let rendered = document.render(&options)?;
53 println!("{rendered}");
54
55 Ok(())
56}Trait Implementations
Sourceimpl Clone for DiagnosticSet
impl Clone for DiagnosticSet
Sourcefn clone(&self) -> DiagnosticSet
fn clone(&self) -> DiagnosticSet
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DiagnosticSet
impl Debug for DiagnosticSet
Sourceimpl Default for DiagnosticSet
impl Default for DiagnosticSet
Sourcefn default() -> DiagnosticSet
fn default() -> DiagnosticSet
Returns the “default value” for a type. Read more
Sourceimpl IntoIterator for DiagnosticSet
impl IntoIterator for DiagnosticSet
Sourcetype Item = Diagnostic
type Item = Diagnostic
The type of the elements being iterated over.
Sourcetype IntoIter = IntoIter<Diagnostic>
type IntoIter = IntoIter<Diagnostic>
Which kind of iterator are we turning this into?
Sourcefn into_iter(self) -> <DiagnosticSet as IntoIterator>::IntoIter
fn into_iter(self) -> <DiagnosticSet as IntoIterator>::IntoIter
Creates an iterator from a value. Read more